==> kubernetes-model-core-4.10.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/NamedExtensionFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import java.lang.StringBuffer;

public interface NamedExtensionFluent<A extends NamedExtensionFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildExtension instead.
 * @return The buildable object.
 */
@Deprecated public HasMetadata getExtension();
    public HasMetadata buildExtension();
    public A withExtension(HasMetadata extension);
    public Boolean hasExtension();
    public A withLimitRangeExtension(LimitRange limitRangeExtension);
    public NamedExtensionFluent.LimitRangeExtensionNested<A> withNewLimitRangeExtension();
    public NamedExtensionFluent.LimitRangeExtensionNested<A> withNewLimitRangeExtensionLike(LimitRange item);
    public A withNamespaceExtension(Namespace namespaceExtension);
    public NamedExtensionFluent.NamespaceExtensionNested<A> withNewNamespaceExtension();
    public NamedExtensionFluent.NamespaceExtensionNested<A> withNewNamespaceExtensionLike(Namespace item);
    public A withServiceExtension(Service serviceExtension);
    public NamedExtensionFluent.ServiceExtensionNested<A> withNewServiceExtension();
    public NamedExtensionFluent.ServiceExtensionNested<A> withNewServiceExtensionLike(Service item);
    public A withReplicationControllerExtension(ReplicationController replicationControllerExtension);
    public NamedExtensionFluent.ReplicationControllerExtensionNested<A> withNewReplicationControllerExtension();
    public NamedExtensionFluent.ReplicationControllerExtensionNested<A> withNewReplicationControllerExtensionLike(ReplicationController item);
    public A withPodTemplateExtension(PodTemplate podTemplateExtension);
    public NamedExtensionFluent.PodTemplateExtensionNested<A> withNewPodTemplateExtension();
    public NamedExtensionFluent.PodTemplateExtensionNested<A> withNewPodTemplateExtensionLike(PodTemplate item);
    public A withEventExtension(Event eventExtension);
    public NamedExtensionFluent.EventExtensionNested<A> withNewEventExtension();
    public NamedExtensionFluent.EventExtensionNested<A> withNewEventExtensionLike(Event item);
    public A withPersistentVolumeExtension(PersistentVolume persistentVolumeExtension);
    public NamedExtensionFluent.PersistentVolumeExtensionNested<A> withNewPersistentVolumeExtension();
    public NamedExtensionFluent.PersistentVolumeExtensionNested<A> withNewPersistentVolumeExtensionLike(PersistentVolume item);
    public A withPersistentVolumeClaimExtension(PersistentVolumeClaim persistentVolumeClaimExtension);
    public NamedExtensionFluent.PersistentVolumeClaimExtensionNested<A> withNewPersistentVolumeClaimExtension();
    public NamedExtensionFluent.PersistentVolumeClaimExtensionNested<A> withNewPersistentVolumeClaimExtensionLike(PersistentVolumeClaim item);
    public A withEndpointsExtension(Endpoints endpointsExtension);
    public NamedExtensionFluent.EndpointsExtensionNested<A> withNewEndpointsExtension();
    public NamedExtensionFluent.EndpointsExtensionNested<A> withNewEndpointsExtensionLike(Endpoints item);
    public A withPodExtension(Pod podExtension);
    public NamedExtensionFluent.PodExtensionNested<A> withNewPodExtension();
    public NamedExtensionFluent.PodExtensionNested<A> withNewPodExtensionLike(Pod item);
    public A withConfigMapExtension(ConfigMap configMapExtension);
    public NamedExtensionFluent.ConfigMapExtensionNested<A> withNewConfigMapExtension();
    public NamedExtensionFluent.ConfigMapExtensionNested<A> withNewConfigMapExtensionLike(ConfigMap item);
    public A withComponentStatusExtension(ComponentStatus componentStatusExtension);
    public NamedExtensionFluent.ComponentStatusExtensionNested<A> withNewComponentStatusExtension();
    public NamedExtensionFluent.ComponentStatusExtensionNested<A> withNewComponentStatusExtensionLike(ComponentStatus item);
    public A withBindingExtension(Binding bindingExtension);
    public NamedExtensionFluent.BindingExtensionNested<A> withNewBindingExtension();
    public NamedExtensionFluent.BindingExtensionNested<A> withNewBindingExtensionLike(Binding item);
    public A withResourceQuotaExtension(ResourceQuota resourceQuotaExtension);
    public NamedExtensionFluent.ResourceQuotaExtensionNested<A> withNewResourceQuotaExtension();
    public NamedExtensionFluent.ResourceQuotaExtensionNested<A> withNewResourceQuotaExtensionLike(ResourceQuota item);
    public A withSecretExtension(Secret secretExtension);
    public NamedExtensionFluent.SecretExtensionNested<A> withNewSecretExtension();
    public NamedExtensionFluent.SecretExtensionNested<A> withNewSecretExtensionLike(Secret item);
    public A withNodeExtension(Node nodeExtension);
    public NamedExtensionFluent.NodeExtensionNested<A> withNewNodeExtension();
    public NamedExtensionFluent.NodeExtensionNested<A> withNewNodeExtensionLike(Node item);
    public A withServiceAccountExtension(ServiceAccount serviceAccountExtension);
    public NamedExtensionFluent.ServiceAccountExtensionNested<A> withNewServiceAccountExtension();
    public NamedExtensionFluent.ServiceAccountExtensionNested<A> withNewServiceAccountExtensionLike(ServiceAccount item);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);

    public interface LimitRangeExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LimitRangeFluent<NamedExtensionFluent.LimitRangeExtensionNested<N>>{

        
    public N and();    public N endLimitRangeExtension();
}
    public interface NamespaceExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NamespaceFluent<NamedExtensionFluent.NamespaceExtensionNested<N>>{

        
    public N and();    public N endNamespaceExtension();
}
    public interface ServiceExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ServiceFluent<NamedExtensionFluent.ServiceExtensionNested<N>>{

        
    public N and();    public N endServiceExtension();
}
    public interface ReplicationControllerExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ReplicationControllerFluent<NamedExtensionFluent.ReplicationControllerExtensionNested<N>>{

        
    public N and();    public N endReplicationControllerExtension();
}
    public interface PodTemplateExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateFluent<NamedExtensionFluent.PodTemplateExtensionNested<N>>{

        
    public N and();    public N endPodTemplateExtension();
}
    public interface EventExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EventFluent<NamedExtensionFluent.EventExtensionNested<N>>{

        
    public N and();    public N endEventExtension();
}
    public interface PersistentVolumeExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PersistentVolumeFluent<NamedExtensionFluent.PersistentVolumeExtensionNested<N>>{

        
    public N and();    public N endPersistentVolumeExtension();
}
    public interface PersistentVolumeClaimExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PersistentVolumeClaimFluent<NamedExtensionFluent.PersistentVolumeClaimExtensionNested<N>>{

        
    public N and();    public N endPersistentVolumeClaimExtension();
}
    public interface EndpointsExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EndpointsFluent<NamedExtensionFluent.EndpointsExtensionNested<N>>{

        
    public N and();    public N endEndpointsExtension();
}
    public interface PodExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodFluent<NamedExtensionFluent.PodExtensionNested<N>>{

        
    public N and();    public N endPodExtension();
}
    public interface ConfigMapExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConfigMapFluent<NamedExtensionFluent.ConfigMapExtensionNested<N>>{

        
    public N and();    public N endConfigMapExtension();
}
    public interface ComponentStatusExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ComponentStatusFluent<NamedExtensionFluent.ComponentStatusExtensionNested<N>>{

        
    public N and();    public N endComponentStatusExtension();
}
    public interface BindingExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BindingFluent<NamedExtensionFluent.BindingExtensionNested<N>>{

        
    public N and();    public N endBindingExtension();
}
    public interface ResourceQuotaExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceQuotaFluent<NamedExtensionFluent.ResourceQuotaExtensionNested<N>>{

        
    public N and();    public N endResourceQuotaExtension();
}
    public interface SecretExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SecretFluent<NamedExtensionFluent.SecretExtensionNested<N>>{

        
    public N and();    public N endSecretExtension();
}
    public interface NodeExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodeFluent<NamedExtensionFluent.NodeExtensionNested<N>>{

        
    public N and();    public N endNodeExtension();
}
    public interface ServiceAccountExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ServiceAccountFluent<NamedExtensionFluent.ServiceAccountExtensionNested<N>>{

        
    public N and();    public N endServiceAccountExtension();
}


}

==> kubernetes-model-core-4.10.3-sources.jar: annotations/io/fabric8/kubernetes/api/model/NamedExtensionFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import java.lang.StringBuffer;

public interface NamedExtensionFluent<A extends NamedExtensionFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildExtension instead.
 * @return The buildable object.
 */
@Deprecated public HasMetadata getExtension();
    public HasMetadata buildExtension();
    public A withExtension(HasMetadata extension);
    public Boolean hasExtension();
    public A withLimitRangeExtension(LimitRange limitRangeExtension);
    public NamedExtensionFluent.LimitRangeExtensionNested<A> withNewLimitRangeExtension();
    public NamedExtensionFluent.LimitRangeExtensionNested<A> withNewLimitRangeExtensionLike(LimitRange item);
    public A withAPIServiceExtension(APIService aPIServiceExtension);
    public NamedExtensionFluent.APIServiceExtensionNested<A> withNewAPIServiceExtension();
    public NamedExtensionFluent.APIServiceExtensionNested<A> withNewAPIServiceExtensionLike(APIService item);
    public A withNamespaceExtension(Namespace namespaceExtension);
    public NamedExtensionFluent.NamespaceExtensionNested<A> withNewNamespaceExtension();
    public NamedExtensionFluent.NamespaceExtensionNested<A> withNewNamespaceExtensionLike(Namespace item);
    public A withServiceExtension(Service serviceExtension);
    public NamedExtensionFluent.ServiceExtensionNested<A> withNewServiceExtension();
    public NamedExtensionFluent.ServiceExtensionNested<A> withNewServiceExtensionLike(Service item);
    public A withReplicationControllerExtension(ReplicationController replicationControllerExtension);
    public NamedExtensionFluent.ReplicationControllerExtensionNested<A> withNewReplicationControllerExtension();
    public NamedExtensionFluent.ReplicationControllerExtensionNested<A> withNewReplicationControllerExtensionLike(ReplicationController item);
    public A withPodTemplateExtension(PodTemplate podTemplateExtension);
    public NamedExtensionFluent.PodTemplateExtensionNested<A> withNewPodTemplateExtension();
    public NamedExtensionFluent.PodTemplateExtensionNested<A> withNewPodTemplateExtensionLike(PodTemplate item);
    public A withEventExtension(Event eventExtension);
    public NamedExtensionFluent.EventExtensionNested<A> withNewEventExtension();
    public NamedExtensionFluent.EventExtensionNested<A> withNewEventExtensionLike(Event item);
    public A withPersistentVolumeExtension(PersistentVolume persistentVolumeExtension);
    public NamedExtensionFluent.PersistentVolumeExtensionNested<A> withNewPersistentVolumeExtension();
    public NamedExtensionFluent.PersistentVolumeExtensionNested<A> withNewPersistentVolumeExtensionLike(PersistentVolume item);
    public A withPersistentVolumeClaimExtension(PersistentVolumeClaim persistentVolumeClaimExtension);
    public NamedExtensionFluent.PersistentVolumeClaimExtensionNested<A> withNewPersistentVolumeClaimExtension();
    public NamedExtensionFluent.PersistentVolumeClaimExtensionNested<A> withNewPersistentVolumeClaimExtensionLike(PersistentVolumeClaim item);
    public A withEndpointsExtension(Endpoints endpointsExtension);
    public NamedExtensionFluent.EndpointsExtensionNested<A> withNewEndpointsExtension();
    public NamedExtensionFluent.EndpointsExtensionNested<A> withNewEndpointsExtensionLike(Endpoints item);
    public A withPodExtension(Pod podExtension);
    public NamedExtensionFluent.PodExtensionNested<A> withNewPodExtension();
    public NamedExtensionFluent.PodExtensionNested<A> withNewPodExtensionLike(Pod item);
    public A withConfigMapExtension(ConfigMap configMapExtension);
    public NamedExtensionFluent.ConfigMapExtensionNested<A> withNewConfigMapExtension();
    public NamedExtensionFluent.ConfigMapExtensionNested<A> withNewConfigMapExtensionLike(ConfigMap item);
    public A withComponentStatusExtension(ComponentStatus componentStatusExtension);
    public NamedExtensionFluent.ComponentStatusExtensionNested<A> withNewComponentStatusExtension();
    public NamedExtensionFluent.ComponentStatusExtensionNested<A> withNewComponentStatusExtensionLike(ComponentStatus item);
    public A withBindingExtension(Binding bindingExtension);
    public NamedExtensionFluent.BindingExtensionNested<A> withNewBindingExtension();
    public NamedExtensionFluent.BindingExtensionNested<A> withNewBindingExtensionLike(Binding item);
    public A withResourceQuotaExtension(ResourceQuota resourceQuotaExtension);
    public NamedExtensionFluent.ResourceQuotaExtensionNested<A> withNewResourceQuotaExtension();
    public NamedExtensionFluent.ResourceQuotaExtensionNested<A> withNewResourceQuotaExtensionLike(ResourceQuota item);
    public A withSecretExtension(Secret secretExtension);
    public NamedExtensionFluent.SecretExtensionNested<A> withNewSecretExtension();
    public NamedExtensionFluent.SecretExtensionNested<A> withNewSecretExtensionLike(Secret item);
    public A withNodeExtension(Node nodeExtension);
    public NamedExtensionFluent.NodeExtensionNested<A> withNewNodeExtension();
    public NamedExtensionFluent.NodeExtensionNested<A> withNewNodeExtensionLike(Node item);
    public A withServiceAccountExtension(ServiceAccount serviceAccountExtension);
    public NamedExtensionFluent.ServiceAccountExtensionNested<A> withNewServiceAccountExtension();
    public NamedExtensionFluent.ServiceAccountExtensionNested<A> withNewServiceAccountExtensionLike(ServiceAccount item);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);

    public interface LimitRangeExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LimitRangeFluent<NamedExtensionFluent.LimitRangeExtensionNested<N>>{

        
    public N and();    public N endLimitRangeExtension();
}
    public interface APIServiceExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,APIServiceFluent<NamedExtensionFluent.APIServiceExtensionNested<N>>{

        
    public N and();    public N endAPIServiceExtension();
}
    public interface NamespaceExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NamespaceFluent<NamedExtensionFluent.NamespaceExtensionNested<N>>{

        
    public N and();    public N endNamespaceExtension();
}
    public interface ServiceExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ServiceFluent<NamedExtensionFluent.ServiceExtensionNested<N>>{

        
    public N and();    public N endServiceExtension();
}
    public interface ReplicationControllerExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ReplicationControllerFluent<NamedExtensionFluent.ReplicationControllerExtensionNested<N>>{

        
    public N and();    public N endReplicationControllerExtension();
}
    public interface PodTemplateExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateFluent<NamedExtensionFluent.PodTemplateExtensionNested<N>>{

        
    public N and();    public N endPodTemplateExtension();
}
    public interface EventExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EventFluent<NamedExtensionFluent.EventExtensionNested<N>>{

        
    public N and();    public N endEventExtension();
}
    public interface PersistentVolumeExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PersistentVolumeFluent<NamedExtensionFluent.PersistentVolumeExtensionNested<N>>{

        
    public N and();    public N endPersistentVolumeExtension();
}
    public interface PersistentVolumeClaimExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PersistentVolumeClaimFluent<NamedExtensionFluent.PersistentVolumeClaimExtensionNested<N>>{

        
    public N and();    public N endPersistentVolumeClaimExtension();
}
    public interface EndpointsExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EndpointsFluent<NamedExtensionFluent.EndpointsExtensionNested<N>>{

        
    public N and();    public N endEndpointsExtension();
}
    public interface PodExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodFluent<NamedExtensionFluent.PodExtensionNested<N>>{

        
    public N and();    public N endPodExtension();
}
    public interface ConfigMapExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConfigMapFluent<NamedExtensionFluent.ConfigMapExtensionNested<N>>{

        
    public N and();    public N endConfigMapExtension();
}
    public interface ComponentStatusExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ComponentStatusFluent<NamedExtensionFluent.ComponentStatusExtensionNested<N>>{

        
    public N and();    public N endComponentStatusExtension();
}
    public interface BindingExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BindingFluent<NamedExtensionFluent.BindingExtensionNested<N>>{

        
    public N and();    public N endBindingExtension();
}
    public interface ResourceQuotaExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceQuotaFluent<NamedExtensionFluent.ResourceQuotaExtensionNested<N>>{

        
    public N and();    public N endResourceQuotaExtension();
}
    public interface SecretExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,SecretFluent<NamedExtensionFluent.SecretExtensionNested<N>>{

        
    public N and();    public N endSecretExtension();
}
    public interface NodeExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NodeFluent<NamedExtensionFluent.NodeExtensionNested<N>>{

        
    public N and();    public N endNodeExtension();
}
    public interface ServiceAccountExtensionNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ServiceAccountFluent<NamedExtensionFluent.ServiceAccountExtensionNested<N>>{

        
    public N and();    public N endServiceAccountExtension();
}


}
